<?php

namespace Drupal\Tests\views_exposed_input_token\Functional;

use Drupal\entity_test\Entity\EntityTest;
use Drupal\Tests\views\Functional\ViewTestBase;

/**
 * Tests the views_exposed_input_token module.
 *
 * Copyright (C) 2024  Library Solutions, LLC (et al.).
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * @group views_exposed_input_token
 */
class ViewsExposedInputTokenTest extends ViewTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'olivero';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'views',
    'views_ui',
    'views_exposed_input_token_views_test',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp($import_test_views = TRUE, $modules = ['views_exposed_input_token_views_test']): void {
    parent::setUp($import_test_views, $modules);

    $this->enableViewsTestModule();
    $this->drupalLogin($this->drupalCreateUser([
      'administer views',
    ]));

    $test_item_count = 25;
    for ($i = 0; $i < $test_item_count; $i++) {
      $entity = EntityTest::create();
      $entity->save();
    }
  }

  /**
   * Tests that the token matches what is generated by `display_link`.
   */
  public function testCompareToDisplayLink() {
    $this->drupalGet('/views-exposed-input-views-test');

    $page = $this->getSession()->getPage();
    $page->fillField('id', '3');
    $page->pressButton('Apply');

    $this->assertSession()->elementsCount('css', '[href$="/views-exposed-input-views-test?id=3"]', 2);

    $page = $this->getSession()->getPage();
    $page->fillField('id', '2');
    $page->pressButton('Apply');

    $this->assertSession()->elementsCount('css', '[href$="/views-exposed-input-views-test?id=2"]', 2);
  }

}
